<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Main Plugin class for managing admin interfaces.
 *
 * @class    MWB_TYO_Admin_Settings
 *
 * @version  1.0.0
 * @package  track-your-order/admin
 * @category Class
 * @author   makewebbetter <webmaster@makewebbetter.com>
 */

if( !class_exists( 'MWB_TYO_Admin_Settings' ) ){

	class MWB_TYO_Admin_Settings{

		/**
		 * This is construct of class
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		
		public function __construct(){
			$this->id = 'mwb_tyo_settings';
			add_filter( 'woocommerce_settings_tabs_array', array($this,'mwb_tyo_add_settings_tab'), 50 );
			add_action( 'woocommerce_settings_tabs_' . $this->id, array($this,'mwb_tyo_settings_tab') );
			add_action( 'woocommerce_settings_save_' . $this->id, array( $this, 'save' ) );
			add_action( 'woocommerce_sections_' . $this->id, array( $this, 'mwb_tyo_output_sections' ) );

			// license validation
			$mwb_wot_license_hash = get_option('mwb_tyo_license_hash');
			$mwb_wot_license_key = get_option('mwb_tyo_license_key');
			$mwb_wot_license_plugin = get_option('mwb_tyo_plugin_name');
			$mwb_wot_hash = md5($_SERVER['HTTP_HOST'].$mwb_wot_license_plugin.$mwb_wot_license_key);
			$mwb_tyo_activation_time = get_option('mwb_tyo_activation_date_time',false);
			if(!$mwb_tyo_activation_time){
				$current_timestamp = current_time('timestamp');
				update_option('mwb_tyo_activation_date_time',$current_timestamp);
				$mwb_tyo_activation_time =$current_timestamp;
			}

			$mwb_tyo_after_time = strtotime('+14 days', $mwb_tyo_activation_time);
			$mwb_tyo_currenttime = current_time('timestamp');
			
			if($mwb_tyo_after_time < $mwb_tyo_currenttime && ($mwb_wot_hash != $mwb_wot_license_hash) ){
				add_action( 'admin_menu', array( $this, 'mwb_tyo_admin_menu_verification' ) );
				add_action('init',array($this,'mwb_tyo_redirect_to_verification'));
			}
		}

		/**
		 * this function will redirect to MWB Order Tracker Verification page
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_tyo_redirect_to_verification()
		{
			if(isset($_GET['page']) && isset($_GET['tab']))
			{
				if($_GET['page'] == 'wc-settings' && $_GET['tab'] == 'mwb_tyo_settings')
				{
					wp_redirect(admin_url( 'admin.php?page=mwb_verification'));
				}
			}
		}


		/**
		 * Add sub menu page to woocommerce setting
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_tyo_admin_menu_verification()
		{
			add_submenu_page( 'woocommerce', __('MWB License',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN), __('MWB ORDER TRACKER LICENSE',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN), 'manage_woocommerce', 'mwb_verification', array($this,'mwb_tyo_ordertracker_verification') );
		}

		/**
		 * This function will include the license page
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_tyo_ordertracker_verification()
		{
			include_once MWB_TRACK_YOUR_ORDER_PATH.'admin/mwb_wot_license.php';
		}

		/**
		 * Add new tab to woocommerce setting
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public static function mwb_tyo_add_settings_tab( $settings_tabs ) {
			$settings_tabs['mwb_tyo_settings'] = __( 'Track Your Order', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN );
			return $settings_tabs;
		}
		
		/**
		 * Save section setting 
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_tyo_settings_tab() {
			global $current_section;
			woocommerce_admin_fields( self::mwb_tyo_get_settings($current_section) );
		}

		/**
		 * Output of section setting 
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_tyo_output_sections() {

			global $current_section;
			$sections = $this->mwb_tyo_get_sections();
			if ( empty( $sections ) || 1 === sizeof( $sections ) ) {
				return;
			}

			echo '<ul class="subsubsub">';

			$array_keys = array_keys( $sections );

			foreach ( $sections as $id => $label ) {
				echo '<li><a href="' . admin_url( 'admin.php?page=wc-settings&tab=' . $this->id . '&section=' . sanitize_title( $id ) ) . '" class="' . ( $current_section == $id ? 'current' : '' ) . '">' . $label . '</a> ' . ( end( $array_keys ) == $id ? '' : '|' ) . ' </li>';
			}
			echo '</ul><br class="clear" />';
		}

		/**
		 * Create section setting 
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_tyo_get_sections() {

			$sections = array(
				''             	=>  __( 'Track Order', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
				'custom_status'	=>  __('Build Custom Order Status',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				'other'     	=>  __( 'Common Setting', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
				'templates'		=> __('Templates',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				'enable_api'	=> __('Shipping Services Integration',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				'new_settings'	=> __('New Settings',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				'tracking_with_google_map' => __('Track Your Order With Google Map',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				'track_with_17track' => __('17 Track Integration',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				'enhanced_tracking'		=> __('Enhanced Tracking',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				);

			return apply_filters( 'mwb_tyo_get_sections' . $this->id, $sections );
		}

		/**
		 * Section setting
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function mwb_tyo_get_settings($current_section) {

			$custom_order_status = get_option('mwb_tyo_new_custom_order_status',array());
			$order_status = array( 'wc-dispatched'=>__('Order Dispatched',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN), 'wc-packed'=>__('Order Packed',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN) , 'wc-shipped'=>__('Order Shipped',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN) );
			if(is_array($custom_order_status) && !empty($custom_order_status)){
				foreach ($custom_order_status as $key => $value) {
					foreach($value as $status_key => $status_value){
						$order_status['wc-'.$status_key] = $status_value;
					}
				}
			}

			$statuses = wc_get_order_statuses();
			$mwb_tyo_statuses = wc_get_order_statuses();
			

			if(isset($statuses['wc-cancelled']))
			{
				unset($statuses['wc-cancelled']);
			}
			if ( 'other' == $current_section ) 
			{
				$settings = array(
					array(
						'title' => __( 'Basic Settings', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'type' 	=> 'title',
						),
					array(
						'title'         => __( 'Main Wrapper Class of Theme', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'          => __( 'Write the main wrapper class of your theme if some design issue arises.', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'          => 'text',
						'id' 		=> 'mwb_tyo_track_order_class'
						),
					array(
						'title'         => __( 'Child Wrapper Class of Theme', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'          => __( 'Write the child wrapper class of your theme if some design issue arises.',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'          => 'text',
						'id' 		=> 'mwb_tyo_track_order_child_class'
						),
					array(
						'title'         => __( 'Tracking Order Page Custom CSS', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'          => __( 'Write the custom css for Tracking Order page.', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'          => 'textarea',
						'id' 		=> 'mwb_tyo_tracking_order_custom_css'
						),
					);
				foreach ($statuses as $key => $value) {
					$key = str_replace('-', '_', $key);
					$text_arr = array( 
						'title'         => __( 'Text for ', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).$value.__(' status on tracking page', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'          => __( 'Write the text for ',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).$value.__(' to be shown on frontend during order tracking.',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'          => 'text',
						'id' 		=> 'mwb_tyo_'.$key.'_text'
						);
					$settings[] = $text_arr; 
				}
				$settings[] = array(
					'type' 	=> 'sectionend',
					);

				return apply_filters( 'mwb_tyo_get_common_settings' . $this->id, $settings );
			}
			else if ('custom_status' == $current_section ){
				include_once MWB_TRACK_YOUR_ORDER_PATH.'admin/custom-order-status.php';
				$settings = array();
				return apply_filters( 'mwb_tyo_get_common_settings' . $this->id, $settings );
			}
			else if('templates'==$current_section)
			{
				include_once MWB_TRACK_YOUR_ORDER_PATH.'admin/track-order-templates.php';
				$settings=array();
				return apply_filters('mwb_tyo_get_track_order_templates'.$this->id, $settings);
			}
			else if('enable_api'==$current_section)
			{
				$settings = array(
					array(
						'title' => __( 'Third Party Shipment Tracking API To Track Order In Real Time', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'type' 	=> 'title',
						),
					array(
						'title'   => __( 'Enable Third Party Tracking Api', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'    => __( 'Enable Third Party Tracking Api', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'default' => 'no',
						'type'    => 'checkbox',
						'id' 	  => 'mwb_tyo_enable_third_party_tracking_api'
						),
					array(
						'title' => __('Enter The Shop Address',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'desc'	=> __('Enter the shop address so that customer can find your store easily',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'	=> 'text',
						'id'	=> 'mwb_tyo_shop_address',
						'desc_tip' => true
						),
					array(
						'title'   => __( 'Enable FedEx Shipment Tracking', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'    => __( 'Enable FedEx Shipment Tracking Api', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'default' => 'no',
						'type'    => 'checkbox',
						'id' 	  => 'mwb_tyo_enable_track_order_using_api'
						),
					array(
						'title' => __('Enter Your FedEx User Key',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'desc'  => __('Enter your FedEx user key',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'  => 'text',
						'id'	=> 'mwb_fedex_userkey',
						'desc_tip' => true
						),
					array(
						'title' => __('Enter Your FedEx User Password',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'desc'  => __('Enter your FedEx user password',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'  => 'text',
						'id'	=> 'mwb_fedex_userpassword',
						'desc_tip' => true
						),
					array(
						'title' => __('Enter Your FedEx Account Number',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'desc'  => __('Enter your FedEx account number',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'  => 'text',
						'id'	=> 'mwb_fedex_account_number',
						'desc_tip' => true
						),
					array(
						'title' => __('Enter Your FedEx Meter Number',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'desc'  => __('Enter your FedEx meter number',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'  => 'text',
						'id'	=> 'mwb_fedex_meter_number',
						'desc_tip' => true
						),
					array(
						'title'   => __( 'Enable Canada Post Shipment Tracking', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'    => __( 'Enable Canada Post Shipment Tracking Api', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'default' => 'no',
						'type'    => 'checkbox',
						'id' 	  => 'mwb_tyo_enable_canadapost_tracking',
						),
					array(
						'title' => __('Enter your Canada Post UserName',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'desc'  => __('Enter your Canada Post UserName Here',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'  => 'text',
						'id'	=> 'mwb_tyo_canadapost_tracking_user_key',
						'desc_tip' => true
						),
					array(
						'title' => __('Enter your Canada Post User Password',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'desc'  => __('Enter your Canada Post User Password Here',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'  => 'text',
						'id'	=> 'mwb_tyo_canadapost_tracking_user_password',
						'desc_tip' => true
						),

					array(
						'title'   => __( 'Enable USPS Shipment Tracking', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'    => __( 'Enable USPS Shipment Tracking Api', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'default' => 'no',
						'type'    => 'checkbox',
						'id' 	  => 'mwb_tyo_enable_usps_tracking',
						),
					array(
						'title' => __('Enter your USPS UserName',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'desc'  => __('Enter your USPS UserName Here',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'  => 'text',
						'id'	=> 'mwb_tyo_usps_tracking_user_key',
						'desc_tip' => true
						),
					array(
						'title' => __('Enter your USPS User Password',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'desc'  => __('Enter your USPS User Password Here',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'type'  => 'text',
						'id'	=> 'mwb_tyo_usps_tracking_user_password',
						'desc_tip' => true
						),

					array(
						'type' 	=> 'sectionend',
						),
					);
				return apply_filters( 'mwb_tyo_get_track_order_settings' . $this->id, $settings );
			}
			else if('new_settings'==$current_section)
			{
				
				$statuses = wc_get_order_statuses();
				$defaultstatuses = array_keys($statuses);
				array_push($defaultstatuses,'wc-dispatched','wc-packed','wc-shipped');
				if(is_array($custom_order_status) && !empty($custom_order_status)){
					foreach ($custom_order_status as $key => $value) {
						foreach($value as $status_key => $status_value){
							array_push($defaultstatuses,'wc-'.$status_key);
						}
					}
				}
				
				$new_order_status = array();
				$mwb_tyo_old_selected_statuses = get_option('mwb_tyo_new_settings_custom_statuses_for_order_tracking',false);

				if(empty($mwb_tyo_old_selected_statuses)){
					update_option('mwb_tyo_new_settings_custom_statuses_for_order_tracking',$defaultstatuses);	
				}
				
				$custom_order_status = get_option('mwb_tyo_new_custom_order_status',array());
				
				$order_status = array( 'wc-packed'=>__('Order Packed',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN) ,'wc-dispatched'=>__('Order Dispatched',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),'wc-shipped'=>__('Order Shipped',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN) );
				if(is_array($custom_order_status) && !empty($custom_order_status)){
					foreach ($custom_order_status as $key => $value) {
						foreach($value as $status_key => $status_value){
							$order_status['wc-'.$status_key] = $status_value;
						}
					}
				}
				$statuses = wc_get_order_statuses();
				foreach($statuses as $keys => $values){
					$order_status[$keys] = $values;
				}
				if(is_array($mwb_tyo_old_selected_statuses) && !empty($mwb_tyo_old_selected_statuses)){
					
					foreach($mwb_tyo_old_selected_statuses as $new_key => $new_value){
						$new_order_status[$new_value] = $order_status[$new_value];

					}
				}

				$flag = false;
				foreach ($order_status as $key => $value) {
					if(!isset($new_order_status[$key])) {
						$new_order_status[$key] = $value;
						$flag = true;
					}
				}

				if( $flag ) 
				{
					$order_status = $new_order_status;
				}
				else
				{
					if(is_array($mwb_tyo_old_selected_statuses) && !empty($mwb_tyo_old_selected_statuses))
					{
						foreach($mwb_tyo_old_selected_statuses as $new_keys => $new_values)
						{
							$mwb_tyo_final_position[$new_values] = $order_status[$new_values];

						}
						$order_status = $mwb_tyo_final_position;
					}
				}
			
				$mwb_tyo_different_date_format = array('d F,Y h:i'=>__('dd Month yyyy T',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),'d/m/y'=> __('dd/mm/yy',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),'d F,Y g:i a'=> __('dd Month,yyyy T AM/PM',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
					'Y/m/d'=>__('yyyy/mm/dd',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),'m/d/Y'=>__('mm/dd/yyyy',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),'d M, y'=>__('d M, yy',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),'D, d M, y'=>__('DD, d MM, yy',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),'y-m-d'=>__('yy-mm-dd',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN));

				$settings = array(
					array(
						'title' => __( 'This Settings Will Work For New Added Templates', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'type' 	=> 'title',
						),
					array(
						'title'    => __( 'Select Your Order Statuses To Show On Front-End For Tracking', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'     => __( 'Select New Order Statuses And Default Statuses Which You Want For Order Tracking, You can change the position of the statuses as you want this section is sortable', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'class'    => 'wc-enhanced-select',
						'css'      => 'min-width:300px;',
						'default'  => '',
						'type'     => 'multiselect',
						'options'  => $order_status,
						'desc_tip' =>  true,
						'id' 		=> 'mwb_tyo_new_settings_custom_statuses_for_order_tracking',
						'desc_tip' =>  true,
						),
					array(
						'title'		=>__('Select Date Format',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'desc'		=>__('Select date format to show on tracking templates',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'class'    =>  'wc-enhanced-select',
						'css'      =>  'min-width:300px;',
						'default'	=> '',
						'type'		=> 'select',
						'options'	=> $mwb_tyo_different_date_format,
						'id'		=> 'mwb_tyo_selected_date_format',
						'desc_tip'	=> true,
						),
					array(
						'type' 	=> 'sectionend',
						),
					);
				return apply_filters('mwb_tyo_all_new_settings'.$this->id, $settings );
			}
			elseif( 'tracking_with_google_map' == $current_section){
					include_once MWB_TRACK_YOUR_ORDER_PATH.'admin/mwb-tyo-track-with-google-map.php';
					$settings = array();
					return apply_filters('mwb_tyo_track_with_google_map'.$this->id,$settings);
			}
			elseif('track_with_17track' == $current_section){
				$settings = array(
					array(
						'title' => __( 'Third Party Shipment Tracking API To Track Order In Real Time With 17Track.net', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'type' 	=> 'title',
						),
					array(
						'title'   => __( 'Enable 17Track.net Tracking Feature', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'    => __( 'Enable 17Track.net tracking Feature if you ship your orders with different shipping companies', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'default' => 'no',
						'type'    => 'checkbox',
						'id' 	  => 'mwb_tyo_enable_17track_integration'
						),
					// array(
					// 	'title' => __('Enter Custom Note For Customer\'s',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
					// 	'desc'	=> __('Enter the any custom note for your customers when they want to track thier orders',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
					// 	'type'	=> 'textarea',
					// 	'id'	=> 'mwb_tyo_custom_note',
					// 	'desc_tip' => true
					// 	),
					array(
						'type' 	=> 'sectionend',
						),
					);
				return apply_filters( 'mwb_tyo_17track_order_settings' . $this->id, $settings );
			}
			elseif('enhanced_tracking' == $current_section){
				include_once MWB_TRACK_YOUR_ORDER_PATH.'admin/enhanced-tracking-settings.php';
				$settings = array();
				return apply_filters('mwb_tyo_enhanced_tracking'.$this->id,$settings);
			}
			else{

				$total_hidden_status = $mwb_tyo_statuses;
				foreach($order_status as $key => $val)
				{
					$total_hidden_status[$key] = $val;
				}
				
				$settings = array(
					array(
						'title' => __( 'Track Your Order', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'type' 	=> 'title',
						),
					array(
						'title'         => __( 'Enable Order tracking Feature', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'          => __( 'Enable Track Your Order Feature', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'default'       => 'no',
						'type'          => 'checkbox',
						'id' 		=> 'mwb_tyo_enable_track_order_feature'
						),
					array(
						'title'		=>__('Enable Pop-up View For Order Tracking',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'desc'		=>__('Enable Track Your Order Feature in pop-up box',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'default'	=>'no',
						'type'		=>'checkbox',
						'id'		=>'mwb_tyo_enable_track_order_popup'
						),
					array(
						'title'         => __( 'Enable Use Of Custom Order Status', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'          => __( 'Enable use of Custom Order Status', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'default'       => 'no',
						'type'          => 'checkbox',
						'id' 		=> 'mwb_tyo_enable_custom_order_feature'
						),
					array(
						'title'    => __( 'Custom Order Statuses', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'     => __( 'Select new Order Status to be created for enhanced order tracking', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'class'    => 'wc-enhanced-select',
						'css'      => 'min-width:300px;',
						'default'  => '',
						'type'     => 'multiselect',
						'options'  => $order_status,
						'desc_tip' =>  true,
						'id' 		=> 'mwb_tyo_new_custom_statuses_for_order_tracking'
						),
					array(
						'title'    => __( 'hidden_status', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'     => __( 'Select Order Status to be shown in the Approval section while order tracking', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'class'    => 'wc-enhanced-select',
						'css'      => 'min-width:300px;',
						'default'  => '',
						'type'     => 'multiselect',
						'options'  => $total_hidden_status,
						'desc_tip' =>  true,
						'id' 		=> 'mwb_tyo_order_status_in_hidden'
						),
					array(
						'title'    => __( 'Approval', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'     => __( 'Select Order Status to be shown in the Approval section while order tracking', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'class'    => 'wc-enhanced-select',
						'css'      => 'min-width:300px;',
						'default'  => '',
						'type'     => 'multiselect',
						'options'  => $mwb_tyo_statuses,
						'desc_tip' =>  true,
						'id' 		=> 'mwb_tyo_order_status_in_approval'
						),
					array(
						'title'    => __( 'Processing', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'     => __( 'Select Order Status to be shown in the Processing section while order tracking', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'class'    => 'wc-enhanced-select',
						'css'      => 'min-width:300px;',
						'default'  => '',
						'type'     => 'multiselect',
						'options'  => $mwb_tyo_statuses,
						'desc_tip' =>  true,
						'id' 		=> 'mwb_tyo_order_status_in_processing'
						),
					array(
						'title'    => __( 'Shipping', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'desc'     => __( 'Select Order Status to be shown in the Shipping section while order tracking', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
						'class'    => 'wc-enhanced-select',
						'css'      => 'min-width:300px;',
						'default'  => '',
						'type'     => 'multiselect',
						'options'  => $mwb_tyo_statuses,
						'desc_tip' =>  true,
						'id' 		=> 'mwb_tyo_order_status_in_shipping'
						),
					array(
						'title'		=>__('Enable E-mail Notification Feature',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'desc'		=>__('Enable to send the e-mail notification to the customer on changing order status',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
						'default'	=>'no',
						'type'		=>'checkbox',
						'id'		=>'mwb_tyo_email_notifier',
						),
					array(
						'type' 	=> 'sectionend',
						),
					);
return apply_filters( 'mwb_tyo_get_track_order_settings' . $this->id, $settings );
}
}

		 /**
	     * Save setting
	     * @author makewebbetter<webmaster@makewebbetter.com>
	     * @link http://www.makewebbetter.com/
	     */
		 public function save() {
		 	global $current_section;
		 	
		 	if('custom_status' == $current_section || 'templates' == $current_section || 'tracking_with_google_map' == $current_section || 'enhanced_tracking'== $current_section)
		 	{

		 		$settings = array();
		 	}
		 	else
		 	{
		 		$settings = $this->mwb_tyo_get_settings( $current_section );
		 	}
		 	WC_Admin_Settings::save_fields( $settings );
		 }
		}
		new MWB_TYO_Admin_Settings();
	}