<?php
/**
 * Exit if accessed directly
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if( !class_exists( 'MWB_Track_Your_Order' ) )
{
	/**
	 * This is class for tracking order and other functionalities .
	 *
	 * @name    Mwb_Track_Your_Order
	 * @category Class
	 * @author   makewebbetter <webmaster@makewebbetter.com>
	 */
	
	class MWB_Track_Your_Order{

		/**
		 * This is construct of class
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		function __construct() 
		{
			$mwb_tyo_activation_time = get_option('mwb_tyo_activation_date_time',false);
			$mwb_wot_license_hash = get_option('mwb_tyo_license_hash');
			$mwb_wot_license_key = get_option('mwb_tyo_license_key');
			$mwb_wot_license_plugin = get_option('mwb_tyo_plugin_name');
			$mwb_wot_hash = md5($_SERVER['HTTP_HOST'].$mwb_wot_license_plugin.$mwb_wot_license_key);

			if($mwb_tyo_activation_time == ''){
				$current_timestamp = current_time('timestamp');
				update_option('mwb_tyo_activation_date_time',$current_timestamp);
				$mwb_tyo_activation_time = $current_timestamp;
			}

			$mwb_tyo_after_time = strtotime('+14 days', $mwb_tyo_activation_time);
			$mwb_tyo_currenttime = current_time('timestamp');


			add_filter( 'admin_enqueue_scripts', array($this, 'mwb_tyo_admin_scripts'));

			add_filter( 'woocommerce_my_account_my_orders_actions', array( $this,'mwb_tyo_add_track_order_button_on_orderpage' ), 10, 2 );
			add_filter( 'template_include', array($this, 'mwb_tyo_include_track_order_page'),10);
			add_filter( 'template_include', array($this, 'mwb_tyo_include_guest_track_order_page'),10);
			add_filter('template_include', array($this,'mwb_ordertracking_page'),10);
			add_action( 'init', array($this, 'mwb_tyo_register_custom_order_status'),5);

			add_filter( 'wc_order_statuses', array($this, 'mwb_tyo_add_custom_order_status'));
			add_action('admin_menu',  array($this, 'mwb_tyo_tracking_order_meta_box'));
			add_action('admin_notices',  array($this, 'mwb_tyo_notifiaction_msg'));
			add_action( 'save_post', array($this, 'mwb_tyo_save_delivery_date_meta'));
			add_action('save_post', array($this,'mwb_tyo_save_shipping_services_meta'));
			add_action('save_post', array($this,'mwb_tyo_save_custom_shipping_cities_meta'));
			add_action( 'wp_enqueue_scripts', array($this, 'mwb_tyo_scripts'));
			add_action( 'woocommerce_order_status_changed' , array( $this, 'mwb_tyo_track_order_status' ), 10 , 3 );
			add_action( 'woocommerce_order_details_after_order_table',array($this, 'mwb_tyo_track_order_button'));
			add_action('wp_ajax_mwb_mwb_create_custom_order_status',array($this,'mwb_mwb_create_custom_order_status'));
			add_action('wp_ajax_mwb_mwb_delete_custom_order_status',array($this,'mwb_mwb_delete_custom_order_status'));

			add_action('wp_ajax_mwb_form_subbmission_data_from_plugin',array($this,'mwb_form_subbmission_data_from_plugin'));

			add_action('wp_ajax_mwb_selected_template',array($this,'mwb_tyo_selected_template'));
			add_action('init',array($this,'mwb_thickbox_view'),10);

			add_filter( 'woocommerce_account_menu_items' , array( $this, 'mwb_tyo_add_shipment_tracking_menu_on_myaccount_page' ), 10 );
			add_action( 'woocommerce_account_mwb-tyo-shipment-tracking_endpoint', array( $this , 'mwb_tyo_shipment_tracking_frontend_page' ), 10 );
			add_action( 'init', array( $this, 'mwb_tyo_shipment_tracking_endpoints' ) );
			add_filter('woocommerce_account_orders_columns',array($this,'mwb_tyo_tracking_number_on_order_page'),10);
			add_action('woocommerce_my_account_my_orders_column_mwb-tyo-shipment-tracking-number',array($this,'mwb_tyo_show_tacking_number'),10);
			add_action('woocommerce_my_account_my_orders_column_mwb_enhanced_add-column',array($this,'mwb_tyo_show_live_tacking_number'),10);
			add_action( 'wp_print_scripts', array( $this, 'mwb_tyo_add_custom_order_status_icon' ) );
			add_action('wp_ajax_mwb_tyo_first_loading_order_status',array($this,'mwb_tyo_first_loading_order_status'));
			add_action('wp_ajax_mwb_tyo_reorder_order_status',array($this,'mwb_tyo_reorder_order_status'));
			add_action( 'mwb_woocommerce_before_main_content',array($this,'mwb_wot_before_main_content'), 10, 1);
			add_filter('mwb_tyo_add_diffrent_shipping_services',array($this,'mwb_tyo_other_shipping_services'),10,1);
			add_action('wp_ajax_mwb_wot_register_license',array($this,'mwb_wot_check_license'));
			add_filter( 'sidebars_widgets', array($this,'mwb_tyo_disable_all_widgets'),10 );
			add_action('wp_ajax_mwb_tyo_insert_address_for_tracking',array($this,'mwb_tyo_insert_address_for_tracking'));
			add_action('wp_ajax_mwb_provider_subbmission_data_from_plugin',array($this,'mwb_tyo_enhanced_insert_provider_url_for_tracking'));
			add_action('wp_ajax_mwb_provider_remove_company_data_from_plugin',array($this,'mwb_tyo_enhanced_remove_company_provider_url_for_tracking'));
			add_action('admin_menu', array($this,'mwb_tyo_woo_ehanced_shipment_tracking_customer_metaboxes'),20);
			$mwb_enhanced_gen_set = get_option('mwb_tyo_general_settings_saved',false);
			if($mwb_enhanced_gen_set['enable_plugin']=='on'&&!empty($mwb_enhanced_gen_set['enable_plugin']))
			{	
				add_action('admin_menu', array($this,'mwb_tyo_woo_ehanced_shipment_courier_company_metaboxes'),10);
				add_filter('mwb_tyo_add_more_columns_on_order_table',array($this,'mwb_tyo_woo_add_column'),10,1);
			}
			add_action('save_post', array($this,'mwb_tyo_woo_ehnanced_once_update_customer_notes'));
			
			// add_action('woocommerce_my_account_my_orders_column_order-number', array($this,'mwb_tyo_add_17track_link'),10);
		}
		
		public function mwb_tyo_woo_add_column($column)
		{ 
			$column['mwb_enhanced_add-column']=__('Live Tracking',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN);
			return $column;
		}
		public function mwb_tyo_woo_ehanced_shipment_courier_company_metaboxes()
		{
			add_meta_box('mwb_tyo_enhanced_cuorier_company', __('Enter Courier Company',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN), array($this, 'mwb_tyo_enhanced_create_courier_company_callback'), 'shop_order', 'side','high');
		}
		public function mwb_tyo_enhanced_create_courier_company_callback()
		{  
			$mwb_enhanced_gen_set = get_option('mwb_tyo_general_settings_saved',false);
			$mwb_enhanced_courier_company=$mwb_enhanced_gen_set["providers_data"];
			global $post;
			$mwb_post_id=$post->ID;
			$mwb_tyo_enhanced_cuorier_company=get_post_meta($mwb_post_id,'mwb_tyo_enhanced_order_company',true);
			$mwb_tyo_enhanced_track_no=get_post_meta($mwb_post_id,'mwb_tyo_enhanced_tracking_no',true);
			
			?>

			<label><?php _e('Select the Company',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN)?></label>
			<select name="mwb_enhnaced_tyo_courier">
				<?php if(!empty($mwb_enhanced_courier_company)){
					foreach ($mwb_enhanced_courier_company as $key => $value) {
						?> 	
						<option 
						<?php if(!empty($mwb_tyo_enhanced_cuorier_company)){selected($value,$mwb_tyo_enhanced_cuorier_company);} ?> 
						value="<?php echo  $value ?>"><?php echo  $key ?></option>	  
						?>
						<?php	
					} 
				} ?>
			</select>
			<div><?php _e('Tracking Number',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN)?></div>

			<input type="text" name="mwb_enhanced_tyo_tracking" value="<?php if(!empty($mwb_tyo_enhanced_track_no)){echo $mwb_tyo_enhanced_track_no;} ?>"></input>
			<?php 
		}
		public function mwb_tyo_woo_ehnanced_once_update_customer_notes()
		{
			global $post;

			if(isset($post)){
				$mwb_post_id=$post->ID;
				$mwb_tyo_enhanced_customer_note = isset($_POST['mwb_tyo_enhanced_customer_note']) ? $_POST['mwb_tyo_enhanced_customer_note'] : '';
				$mwb_tyo_enhanced_company_courier = isset($_POST['mwb_enhnaced_tyo_courier']) ? $_POST['mwb_enhnaced_tyo_courier'] : '';
				$mwb_tyo_enhanced_tracking_no = isset($_POST['mwb_enhanced_tyo_tracking']) ? $_POST['mwb_enhanced_tyo_tracking'] : '';
				update_post_meta($mwb_post_id,'mwb_tyo_enhanced_cn',$mwb_tyo_enhanced_customer_note);
				update_post_meta($mwb_post_id,'mwb_tyo_enhanced_order_company',$mwb_tyo_enhanced_company_courier);
				update_post_meta($mwb_post_id,'mwb_tyo_enhanced_tracking_no',$mwb_tyo_enhanced_tracking_no);
			}
		}
		public function mwb_tyo_woo_ehanced_shipment_tracking_customer_metaboxes()
		{

			add_meta_box('mwb_tyo_enhanced_customer_note', __('Enter Customer Notes',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN), array($this, 'mwb_tyo_enhanced_create_customer_note_metabox'), 'shop_order','side','high');

		}
		public function mwb_tyo_enhanced_create_customer_note_metabox()
		{   
			
			global $post;
			$mwb_post_id=$post->ID;
			$mwb_tyo_enhanced_customer_note=get_post_meta($mwb_post_id,'mwb_tyo_enhanced_cn',true);
			if(!empty($mwb_tyo_enhanced_customer_note))
			{
				$mwb_tyo_customer_val=$mwb_tyo_enhanced_customer_note;
			}
			else
			{
				$mwb_tyo_customer_val='';
			}
			?>
			<label for="mwb_enhanced_customer_note"><?php _e('Customer Note','') ?></label>
			<?php
			$tip_descriptions = __( 'Enter The customer note that will display on the order details page.',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN);
			echo wc_help_tip( $tip_descriptions ); 
			?>
			<textarea id="mwb_enhanced_customer_note" name="mwb_tyo_enhanced_customer_note"><?php echo htmlspecialchars($mwb_tyo_customer_val);?></textarea>
			<?php 
		}
		public function mwb_tyo_enhanced_remove_company_provider_url_for_tracking()
		{
			$mwb_enhanced_toy_default_company=(!empty($_POST['mwb_company_name']))?$_POST['mwb_company_name']:'';
			$mwb_enhanced_toy_provider_array = get_option('mwb_tyo_courier_companies',false);

			if(!empty($mwb_enhanced_toy_provider_array)&&!empty($mwb_enhanced_toy_default_company))
			{
				unset($mwb_enhanced_toy_provider_array[$mwb_enhanced_toy_default_company]);
				update_option("mwb_tyo_courier_companies",$mwb_enhanced_toy_provider_array);
				print_r($mwb_enhanced_toy_provider_array);
			}
			wp_die();
		}
		public function mwb_tyo_enhanced_insert_provider_url_for_tracking()
		{
			
			$mwb_enhanced_toy_provider_name=(!empty($_POST['mwb_company_name']))?$_POST['mwb_company_name']:'';
			$mwb_enhanced_toy_provider_url=(!empty($_POST['mwb_company_url']))?$_POST['mwb_company_url']:'';
			$mwb_carrier_company=get_option('mwb_tyo_courier_companies',false);
			$mwb_enhanced_toy_provider_array=array($mwb_enhanced_toy_provider_name=>$mwb_enhanced_toy_provider_url);
			$mwb_enhanced_final_array=array_merge($mwb_carrier_company,$mwb_enhanced_toy_provider_array);

			update_option('mwb_tyo_courier_companies',$mwb_enhanced_final_array);
			echo json_encode($mwb_enhanced_toy_provider_array);
			wp_die();
		}
		public function mwb_tyo_add_17track_link($order){
			if(isset($order)){
				$order_id = $order->get_id();
				$tracking_number = get_post_meta($order_id,'mwb_tyo_package_tracking_number',true);
				?>
				<a href="#" id="YQElem1"><?php _e('Track',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN); ?></a>
				<?php
			}
		}

		public function mwb_tyo_insert_address_for_tracking(){

			$mwb_tyo_address_collections = isset($_POST['mwb_tyo_addresses']) ? $_POST['mwb_tyo_addresses'] : '';
			$mwb_tyo_previous_address = get_option('mwb_tyo_old_addresses',array());
			if(is_array($mwb_tyo_previous_address)){

				$mwb_tyo_previous_address['mwb_address_'.$mwb_tyo_address_collections] = $mwb_tyo_address_collections;
				update_option('mwb_tyo_old_addresses',$mwb_tyo_previous_address);
			}

			$mwb_tyo_address_array_value = get_option('mwb_tyo_old_addresses',false);
			echo json_encode($mwb_tyo_address_array_value);
			wp_die();
		}
		

		/**
		 * This function is for removing sidebar from custom pages
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown 
		*/
		public function mwb_tyo_disable_all_widgets( $sidebars_widgets ) {
			
			$track_page_id = get_option( 'mwb_tyo_tracking_page', array() );
			if(strpos($_SERVER['REQUEST_URI'],'/track-your-order') > 0 || strpos($_SERVER['REQUEST_URI'],'/guest-track-order-form') > 0 || strpos($_SERVER['REQUEST_URI'],'/track-fedex-order') > 0 ){
				
				$sidebars_widgets = array( false );
			}
			return $sidebars_widgets;
		}

		
		/**
		 * This function is for accepting license for order tracker plugin
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown 
		*/
		public function mwb_wot_check_license()
		{

			check_ajax_referer( 'mwb-tyo-ajax-seurity-string', 'mwb_nonce' );
			$mwb_license_key = sanitize_text_field( $_POST['license_key'] );

			$mwb_admin_name = '';
			$mwb_admin_email = get_option( 'admin_email', null );
			$mwb_admin_details = get_user_by('email', $admin_email);
			if(isset($mwb_admin_details->data))
			{
				if(isset($mwb_admin_details->data->display_name))
				{
					$mwb_admin_name = $mwb_admin_details->data->display_name;
				}
			}

			$mwb_license_arr = array(
				'license_key' => $mwb_license_key,
				'domain_name' => $_SERVER['HTTP_HOST'],
				'admin_name' => $mwb_admin_name,
				'admin_email' => $mwb_admin_email,
				'plugin_name' => 'woocommerce order tracker'
				);

			$curl = curl_init();

			curl_setopt_array($curl, array(
				CURLOPT_URL => "https://makewebbetter.com/codecanyon/validate_license.php",
				CURLOPT_RETURNTRANSFER => true,
				CURLOPT_ENCODING => "",
				CURLOPT_MAXREDIRS => 10,
				CURLOPT_SSL_VERIFYHOST => false,
				CURLOPT_SSL_VERIFYPEER => false,
				CURLOPT_TIMEOUT => 30,
				CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
				CURLOPT_CUSTOMREQUEST => "POST",
				CURLOPT_POSTFIELDS => http_build_query($mwb_license_arr),
				CURLOPT_HTTPHEADER => array(
					"cache-control: no-cache",
					"content-type: application/x-www-form-urlencoded",
					"postman-token: d9d9a28b-94cc-7a0e-47b2-5bd10aa7aa89"
					),
				));

			$mwb_res = curl_exec($curl);
			$err = curl_error($curl);

			curl_close($curl);

			if ($err) {
				echo "cURL Error #:" . $err;
			}
			$mwb_res = json_decode($mwb_res,true);

			if( $mwb_res['status'] == true)
			{
				update_option('mwb_tyo_license_hash',$mwb_res['hash']);
				update_option('mwb_tyo_plugin_name','woocommerce order tracker');
				update_option('mwb_tyo_license_key',$mwb_res['mwb_key']);
				echo json_encode( array('status'=>true,'msg'=>__('Successfully Verified',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN) ) );
			}
			else if( $mwb_res['status'] == false )
			{
				echo json_encode( array('status'=>false,'msg'=> $mwb_res['msg']) );
			}
			wp_die();
		}

		public function mwb_tyo_other_shipping_services($shipping_company)
		{
			$mwb_tyo_enable_canadapost_api = get_option('mwb_tyo_enable_canadapost_tracking',false);
			$mwb_tyo_enable_usps_api = get_option('mwb_tyo_enable_usps_tracking',false);
			if(isset($mwb_tyo_enable_canadapost_api) && $mwb_tyo_enable_canadapost_api == 'yes'){
				
				$shipping_company['canada_post'] = __('Canada Post',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN);
			}
			if(isset($mwb_tyo_enable_usps_api) && $mwb_tyo_enable_usps_api == 'yes'){
				$shipping_company['usps'] = __('USPS',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN);
			}
			return $shipping_company;
		}

		public function mwb_wot_before_main_content($order_id){

			$mwb_status_change_time_template = get_post_meta($order_id,'mwb_track_order_onchange_time_template', true);

			if(empty($mwb_status_change_time_template)){
				
				$mwb_tyo_email_notifier=get_option('mwb_tyo_email_notifier','no');
				$mwb_tyo_selected_date_format = get_option('mwb_tyo_selected_date_format',false);
				$order = new WC_Order( $order_id );
				
				if(WC()->version < '3.0.0')
				{
					$mwb_date_on_order_change=$order->modified_date;

				}
				else
				{
					$mwb_tyo_order_data_status = $order->get_data()['status'];
					$mwb_tyo_order_data_modified_date = $order->get_data()['date_modified'];
					$date_on_order_change = $order->get_data();

					if(isset($mwb_tyo_order_data_status) && !empty($mwb_tyo_order_data_status))
					{

						$change_order_status=$order->get_data()['status'];
						get_the_modified_date($order);
						$mwb_date_on_order_change = $date_on_order_change['date_modified']->date;	
					}
					else
					{
						$change_order_status = '';
						$mwb_date_on_order_change = '';
					}

				}

				if(isset($mwb_tyo_selected_date_format) && !empty($mwb_tyo_selected_date_format))
				{
					$mwb_tyo_converted_date  = strtotime($mwb_date_on_order_change);
					$mwb_modified_date = date_i18n($mwb_tyo_selected_date_format,$mwb_tyo_converted_date);

				}
				else
				{
					$mwb_modified_date = date_i18n( 'F d, g:i a', strtotime( $mwb_date_on_order_change ));
				}
				
				$mwb_status_change_time = array();
				$mwb_status_change_time_temp = array();
				$mwb_status_change_time = get_post_meta( $order_id, 'mwb_track_order_onchange_time', true );
				$mwb_status_change_time_temp = get_post_meta( $order_id, 'mwb_track_order_onchange_time_temp', true );
				$mwb_status_change_time_template2 = get_post_meta( $order_id, 'mwb_track_order_onchange_time_template', true );
				$mwb_status_change_time['wc-'.$change_order_status]=$mwb_modified_date;
				$mwb_status_change_time_temp[]['wc-'.$change_order_status]=$mwb_modified_date;
				update_post_meta($order_id,'mwb_track_order_onchange_time_template',$mwb_status_change_time_temp);

			}
		}

		/**
		 * This function is for selecting default woocommerce order statuses in database
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown 
		*/
		public function mwb_tyo_first_loading_order_status()
		{

			$mwb_tyo_all_first_time_status = isset($_POST['mwb_first_selected_all_status']) ? $_POST['mwb_first_selected_all_status'] : " ";
			update_option('mwb_tyo_statuses_for_order_tracking_on_activation',$mwb_tyo_all_first_time_status);
			echo "success";
			wp_die();
		}


		/**
		 * This function is for reordering of selected order statuses
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown 
		*/
		public function mwb_tyo_reorder_order_status(){
			
			$mwb_tyo_old_selected_statuses = get_option('mwb_tyo_new_settings_custom_statuses_for_order_tracking',false);
			
			$mwb_tyo_reorder_status_position = isset($_POST['mwb_wot_selected_method']) ? $_POST['mwb_wot_selected_method'] : '';

			if(is_array($mwb_tyo_reorder_status_position) && !empty($mwb_tyo_reorder_status_position)){
				foreach($mwb_tyo_reorder_status_position as $reorder_key => $reorder_value){

					if(in_array($reorder_value, $mwb_tyo_old_selected_statuses)){
						
						$mwb_tyo_reorder_status_position_final[] =  $reorder_value;
					}
				}
			}
			
			update_option('mwb_tyo_new_settings_custom_statuses_for_order_tracking',$mwb_tyo_reorder_status_position_final);
			echo "success";
			wp_die();
		}
		
		public function mwb_tyo_notifiaction_msg()
		{
			$mwb_tyo_msg = get_option('mwb_tyo_warning_notification_message',false);
			if(isset($mwb_tyo_msg) && $mwb_tyo_msg != '')
			{
				?>
				<div class="notice notice-success is-dismissible">
					<p><?php echo $mwb_tyo_msg; ?></p>
				</div>
				<?php
			}
		}

		/**
		 * This function is for accepting update request from clients.
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */

		public function mwb_form_subbmission_data_from_plugin()
		{
			$mwb_tyo_notification = isset($_POST['notification']) ? $_POST['notification'] : 'no';
			update_option('mwb_tyo_warning_notification',$mwb_tyo_notification);
			mwb_tyo_daily_notification_cron();
		}

		/**
		 * This function is to include the image icons on order edit page for custom order status
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */

		public function mwb_tyo_add_custom_order_status_icon()
		{
			if( ! is_admin() ) { 
				return; 
			}

			$custom_order_status=get_option('mwb_tyo_new_custom_order_status',array());
			$custom_order_image = get_option('mwb_tyo_new_custom_order_image',false);
			$mwb_home_url = get_home_url();
			foreach ($custom_order_status as $key => $value) {
				foreach($value as $img_key => $img_value){
					$url = str_replace($mwb_home_url,'..', $custom_order_image[$img_key]);
					?> <style>
					/* Add custom status order icons */
					.widefat .column-order_status mark<?php echo '.'.$img_key; ?> { 
						background-image: url(<?php echo $url; ?>);
						width:17px!important;
						height:17px!important;
						background-size: 100% 100%;
					}

					/* Repeat for each different icon; tie to the correct status */

				</style> <?php
			}
		}
	}

		/**
		 * This function is to include the coulmn on myaccount order section
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_tyo_tracking_number_on_order_page($columns)
		{
			unset($columns['order-actions']);
			$columns['mwb-tyo-shipment-tracking-number'] =  __( '17Tracking Id' , MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN );
			$columns = apply_filters( 'mwb_tyo_add_more_columns_on_order_table' , $columns );
			$columns['order-actions'] = '&nbsp;';
			return $columns;

		}


		/**
		 * This function is to display tracking number on myaccount order section
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_tyo_show_tacking_number($order)
		{
			if(WC()->version < '3.0.0'){
				$mwb_order = $order->post;
				$order_id = $mwb_order->ID;
			}
			else{
				$mwb_order = $order->get_data();
				$order_id = $mwb_order['id'];
			}
			$mwb_tracking_number = get_post_meta($order_id,'mwb_tyo_package_tracking_number',true);
			if(isset($mwb_tracking_number) && $mwb_tracking_number != ''){

				echo '<a href="#" class="button mwb_tyo_17track" id="YQElem1">'.$mwb_tracking_number.'</a>';
			}else{
				$value = __("N/A",MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN);
				echo $value;
			}
		}


		/**
		 * This function is to display tracking number on myaccount order section
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_tyo_show_live_tacking_number($order)
		{
			if(WC()->version < '3.0.0'){
				$mwb_order = $order->post;
				$order_id = $mwb_order->ID;
			}
			else{
				$mwb_order = $order->get_data();
				$order_id = $mwb_order['id'];
			}
			$mwb_tracking_url = get_post_meta($order_id,'mwb_tyo_enhanced_order_company',true);
			$mwb_tracking_number=get_post_meta($order_id,'mwb_tyo_enhanced_tracking_no',true);
			if(isset($mwb_tracking_number) && $mwb_tracking_number != ''){

				echo '<a id="mwb_live_tracking" href="'.$mwb_tracking_url.'" class="button">'.$mwb_tracking_number.'</a>';
			}else{
				$value = __("N/A",MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN);
				echo $value;
			}
		}

		/**
		 * This function is to include and display shipment tracking option in menu on myaccount page
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */

		public function mwb_tyo_add_shipment_tracking_menu_on_myaccount_page( $items )
		{

			unset($items['customer-logout']);
			//$items['mwb-tyo-shipment-tracking'] =  __( 'Shipment Tracking' , MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN );
			$items['customer-logout'] = __( 'Logout', 'woocommerce' );
			$items = apply_filters( 'mwb_tyo_add_more_menu_on_myaccount_page' , $items );
			return $items;
		}

		/**
		 * This function is to include the tracking page on myaccount page under shipment tracking menu option
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_tyo_shipment_tracking_frontend_page()
		{
			include MWB_TRACK_YOUR_ORDER_PATH.'template/mwb-order-tracking-page.php';
		}


		/**
		 * This function is to define the endpoint of shipment tracking option in myaccount menu option
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_tyo_shipment_tracking_endpoints() {
			add_rewrite_endpoint( 'mwb-tyo-shipment-tracking', EP_ROOT | EP_PAGES );
		}

		
		public function mwb_thickbox_view()
		{
			add_thickbox();
		}
		/**
		 * This function is to include CSS and js
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_tyo_scripts()
		{		

			$url = plugins_url();
			$mwb_tyo_enable_track_order_feature=get_option('mwb_tyo_enable_track_order_feature','no');
			$mwb_tyo_enable_track_order_popup=get_option('mwb_tyo_enable_track_order_popup','no');
			$mwb_tyo_enable_templates=get_option('mwb_tyo_enable_templates','no');
			$ajax_nonce = wp_create_nonce( "mwb-tyo-ajax-seurity-string" );
			$upload_url = home_url();
			$mwb_tyo_order_production_add  = get_option('mwb_tyo_order_production_address',false);
			// wp_enqueue_style( 'mwb-tyo-style-front', MWB_TRACK_YOUR_ORDER_URL.'/assets/css/mwb-tyo-style-front.css',MWB_TRACK_YOUR_ORDER_VERSION );
			$user_id = get_current_user_id();
			
			$redirect_uri = $_SERVER['REQUEST_URI'];
			

			$track_page_id = get_option( 'mwb_tyo_tracking_page', array() );
			if( is_array($track_page_id) && !empty( $track_page_id ) )
			{
				$logedin_track_page_id = $track_page_id['pages']['mwb_track_order_page'] ;
				$guest_track_page_id = $track_page_id['pages']['mwb_guest_track_order_page'] ;
				
				if(strpos($_SERVER['REQUEST_URI'],'/track-your-order') > 0 || strpos($_SERVER['REQUEST_URI'],'/guest-track-order-form') > 0){
					wp_enqueue_style( 'mwb-tyo-style-front', MWB_TRACK_YOUR_ORDER_URL.'assets/css/mwb-tyo-style-front.css',"7.4",false);
				}

			}
			$mwb_tyo_pages= get_option('mwb_tyo_tracking_page');
			if(is_array($mwb_tyo_pages) && !empty($mwb_tyo_pages))
			{
				$fedex_page_id = $mwb_tyo_pages['pages']['mwb_fedex_track_order'];
				if($fedex_page_id == get_the_ID())
				{
					wp_enqueue_style( 'mwb-tyo-style-front', MWB_TRACK_YOUR_ORDER_URL.'/assets/css/mwb-tyo-style-front.css',"5.6");
					
				}
			}

			if(strpos($_SERVER['REQUEST_URI'],'/track-your-order') > 0 || strpos($_SERVER['REQUEST_URI'],'/guest-track-order-form') > 0){
				wp_enqueue_script('17track-js','//www.17track.net/externalcall.js','' ,MWB_TRACK_YOUR_ORDER_VERSION,true);

				wp_register_script('mwb-tyo-script', MWB_TRACK_YOUR_ORDER_URL.'assets/js/mwb-tyo-script.js', array('jquery'), '5.3' , true);
				$ajax_nonce = wp_create_nonce( "mwb-tyo-ajax-seurity-string" );
				$statuses = wc_get_order_statuses();
				$translation_array = array(
					'ajaxurl' => admin_url('admin-ajax.php'),
					'mwb_tyo_nonce'	=>	$ajax_nonce,
					'order_statuses'	=>	$statuses,
					'order_feature_enable'=>$mwb_tyo_enable_track_order_feature,
					'order_feature_popup'=>$mwb_tyo_enable_track_order_popup,
					'track_order_template'=>$mwb_tyo_enable_templates,
					);
				wp_localize_script( 'mwb-tyo-script', 'global_tyo', $translation_array );
				wp_enqueue_script( 'mwb-tyo-script' );
			}


			if(strpos($_SERVER['REQUEST_URI'],'/mwb-tyo-shipment-tracking') > 0)
			{
				wp_enqueue_script( 'mwb-tyo-script', MWB_TRACK_YOUR_ORDER_URL.'/assets/js/mwb-tyo-script.js',array('jquery'),MWB_TRACK_YOUR_ORDER_VERSION,true );
			}

			wp_enqueue_script('mwb-tyo-script-velocity',MWB_TRACK_YOUR_ORDER_URL.'assets/js/velocity.min.js',array('jquery'),MWB_TRACK_YOUR_ORDER_VERSION,true);
			wp_enqueue_script('mwb-tyo-script-jquery',MWB_TRACK_YOUR_ORDER_URL.'assets/js/jquery-ui.js','',MWB_TRACK_YOUR_ORDER_VERSION,true);
			wp_enqueue_script('mwb-tyo-script-jquery-min',MWB_TRACK_YOUR_ORDER_URL.'assets/js/jquery-ui.min.js','',MWB_TRACK_YOUR_ORDER_VERSION,true);
			

			if(strpos($_SERVER['REQUEST_URI'],'/track-your-order') > 0)
			{
				$mwb_enable_google_map = get_option('mwb_tyo_google_api_settings','');

				if(isset($mwb_enable_google_map) && ( $mwb_enable_google_map != 0 || $mwb_enable_google_map != '' || $mwb_enable_google_map != null))
				{
					wp_enqueue_script('mwb_new_road_map_script','https://maps.googleapis.com/maps/api/js?key=AIzaSyBJxgQFUgUqCX2CvXZlzP3bRb4GoWL28NQ','',MWB_TRACK_YOUR_ORDER_VERSION,true);
					
					wp_register_script('mwb-tyo-new-script', MWB_TRACK_YOUR_ORDER_URL.'assets/js/mwb-tyo-new-frontend.js', array('jquery'), '5.6' , true);
					$ajax_nonce = wp_create_nonce( "mwb-tyo-ajax-seurity-string" );
					$statuses = wc_get_order_statuses();
					$translation_array = array(
						'ajaxurl' => admin_url('admin-ajax.php'),
						'mwb_tyo_nonce'	=>	$ajax_nonce,
						'order_statuses'	=>	$statuses,
						'order_feature_enable'=>$mwb_tyo_enable_track_order_feature,
						'order_feature_popup'=>$mwb_tyo_enable_track_order_popup,
						'track_order_template'=>$mwb_tyo_enable_templates,
						'track_order_order_origin'=>$mwb_tyo_order_production_add,
						);
					wp_localize_script( 'mwb-tyo-new-script', 'global_new_tyo', $translation_array );
					wp_enqueue_script( 'mwb-tyo-new-script' );
				}
			}

			
			// wp_enqueue_script('mwb-wtyo-js',MWB_TRACK_YOUR_ORDER_URL.'assets/js/track.js', array('jquery','mwb-tyo-17track-js'), '5.7' , true);
			
			
		}
		/**
		 * This function is add cs and js to order meta
		 * 
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown $order
		 */
		public function mwb_tyo_admin_scripts()
		{

			$flag_counter = 0;
			$flag_counter_after = 0;
			$screen = get_current_screen();
			$mwb_tyo_selected_statuses = get_option('mwb_tyo_statuses_for_order_tracking_on_activation',false);
			$mwb_tyo_selected_statuses_after_save = get_option('mwb_tyo_new_settings_custom_statuses_for_order_tracking',false);
			// $mwb_tyo_wp_pointer_ending_point = get_option('mwb_tyo_wp_pointer_end_section_option');
			if(is_array($mwb_tyo_selected_statuses) && !empty($mwb_tyo_selected_statuses) )
			{
				$flag_counter = 1;
			}

			if(is_array($mwb_tyo_selected_statuses_after_save) && !empty($mwb_tyo_selected_statuses_after_save))
			{
				$flag_counter_after = 1;
			}
			
			$screen = get_current_screen();

			if(isset($screen->id))
			{	
				if($screen->id == 'shop_order')
				{
					wp_enqueue_style( 'mwb-tyo-style-jqueru-ui', MWB_TRACK_YOUR_ORDER_URL.'assets/css/jquery-ui.css' );
					wp_enqueue_style( 'mwb-tyo-style-timepicker', MWB_TRACK_YOUR_ORDER_URL.'assets/css/jquery.ui.timepicker.css' );
					wp_enqueue_script( 'mwb-tyo-script-timepicker', MWB_TRACK_YOUR_ORDER_URL.'assets/js/jquery.ui.timepicker.js', array('jquery'), MWB_TRACK_YOUR_ORDER_VERSION, true );
					wp_enqueue_script( 'jquery-ui-datepicker' );
					
				}

			}
			wp_register_script('mwb-tyo-script-admin', MWB_TRACK_YOUR_ORDER_URL.'assets/js/mwb-tyo-admin-script.js', array('jquery'), MWB_TRACK_YOUR_ORDER_VERSION);
			if( strpos($_SERVER['REQUEST_URI'], '&tab=mwb_tyo_settings') > 0 )
			{
				wp_enqueue_script( 'select2' );
				wp_enqueue_style( 'select2' );
			}

			$ajax_nonce = wp_create_nonce( "mwb-tyo-ajax-seurity-string" );
			$statuses = wc_get_order_statuses();
			$order_status = array( 'wc-dispatched'=>__('Order Dispatched',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN), 'wc-packed'=>__('Order Packed',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN) , 'wc-shipped'=>__('Order Shipped',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN) );
			$custom_order_status=get_option('mwb_tyo_new_custom_order_status',array());
			if(is_array($custom_order_status) && !empty($custom_order_status)){
				foreach ($custom_order_status as $key => $value) {
					foreach($value as $status_key => $status_value){
						$order_status['wc-'.$status_key] = $status_value;
					}
				}
			}
			foreach($order_status as $key => $val)
			{
				$statuses[$key] = $val;
			}

			$translation_array = array(
				'ajaxurl' => admin_url('admin-ajax.php'),
				'mwb_tyo_nonce'	=>	$ajax_nonce,
				'site_url' => site_url(),
				'order_statuses'	=>	$statuses,
				'default_enable_statuses' => $flag_counter,
				'after_save_statuses' => $flag_counter_after,
				'mwb_tyo_close_button' => __('Close',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				'message_success'  => __( 'Order Status successfully saved.', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
				'message_invalid_input'  => __( 'Please enter a Valid Status Name.', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN  ),
				'message_error_save'  => __( 'Unable to save Order Status.', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
				'message_empty_data'  => __( 'Please enter the status name .',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ),
				'message_template_activated' => __('Template Activated sucessfully.',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				);
			wp_enqueue_style( 'mwb-tyo-style', MWB_TRACK_YOUR_ORDER_URL.'/assets/css/mwb-tyo-style.css',array(),MWB_TRACK_YOUR_ORDER_VERSION );
			wp_localize_script( 'mwb-tyo-script-admin', 'global_tyo', $translation_array );
			wp_enqueue_script( 'mwb-tyo-script-admin' );
			// wp_enqueue_script( 'jquery-ui-sortable' );
			if(isset($_GET['page']) && isset($_GET['tab']) && isset($_GET['section']))
			{
				if($_GET['page'] == 'wc-settings' && $_GET['tab'] == 'mwb_tyo_settings' && $_GET['section'] == 'new_settings')
				{
					
					wp_enqueue_script('mwb-tyo-script-admin-jquery',MWB_TRACK_YOUR_ORDER_URL.'assets/js/jquery-ui.js',array('jquery-ui-sortable'),MWB_TRACK_YOUR_ORDER_VERSION,true);
					wp_register_script('mwb-tyo-admin-status-reorder',MWB_TRACK_YOUR_ORDER_URL.'assets/js/mwb-tyo-admin-status-sortable.js',array('jquery','jquery-ui-sortable'),MWB_TRACK_YOUR_ORDER_VERSION,true);
					$mwb_tyo_sortable_array = array(
						'adminajaxurl' => admin_url('admin-ajax.php'),
						'site_url' => site_url(),
						'order_statuses'	=>	$statuses,
						'default_enable_statuses' => $flag_counter,
						'after_save_statuses' => $flag_counter_after,
						);
					wp_localize_script('mwb-tyo-admin-status-reorder','mwb_tyo_reorder_param',$mwb_tyo_sortable_array);
					wp_enqueue_script('mwb-tyo-admin-status-reorder');
				}	
			}
			wp_register_script('mwb-tyo-new-tracking-js',MWB_TRACK_YOUR_ORDER_URL.'assets/js/mwb-tyo-new-tracking.js',array('jquery'),MWB_TRACK_YOUR_ORDER_VERSION,true);
			$mwb_tyo_new_settings_array = array(
				'adminajaxurl' => admin_url('admin-ajax.php'),
				'site_url' => site_url(),
				'address_validation' => __('Please Enter Address First',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				'address_validation_success' => __('Address Successfully Added',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				'selec_address_placeholder' => __('Select Your Hubpoint Addresses',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				);
			wp_localize_script('mwb-tyo-new-tracking-js','mwb_tyo_new_param',$mwb_tyo_new_settings_array);
			wp_enqueue_script('mwb-tyo-new-tracking-js');
		}

		/**
		 * This function adds a Custom order status on the backend
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown $template
		 */
		public function mwb_mwb_create_custom_order_status()
		{
			$create_custom_order_status = array();
			$value = array();
			$custom_order_image_url = array();
			$mwb_image_url = array();
			$value = get_option('mwb_tyo_new_custom_order_status',false);
			$custom_order_image_url = get_option('mwb_tyo_new_custom_order_image',false);
			if(is_array($value) && !empty($value))
			{
				$create_custom_order_status=$_POST['mwb_mwb_new_role_name'];
				$create_custom_order_image_url = $_POST['mwb_custom_order_image_url'];
				$key_custom_order_status = str_replace(' ', '', $create_custom_order_status);
				$key_custom_order_status = strtolower($key_custom_order_status);
				$value[] = array( $key_custom_order_status => $create_custom_order_status);
				$custom_order_image_url[$key_custom_order_status ] = $create_custom_order_image_url;

				update_option('mwb_tyo_new_custom_order_status',$value);
				update_option('mwb_tyo_new_custom_order_image',$custom_order_image_url);

			}else{
				$create_custom_order_status=$_POST['mwb_mwb_new_role_name'];
				$create_custom_order_image_url = $_POST['mwb_custom_order_image_url'];
				$key_custom_order_status = str_replace(' ', '', $create_custom_order_status);
				$key_custom_order_status = strtolower($key_custom_order_status);
				$value[] = array( $key_custom_order_status => $create_custom_order_status);
				$custom_order_image_url[$key_custom_order_status ] = $create_custom_order_image_url;

				update_option('mwb_tyo_new_custom_order_status',$value);
				update_option('mwb_tyo_new_custom_order_image',$custom_order_image_url);
			}
			
			echo "success";
			wp_die();
		}

		/**
		 * This function delete the Custom order status on the backend
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown $template
		 */

		public function mwb_tyo_selected_template()
		{
			$selected_template_name=$_POST['template_name'];
			update_option('mwb_tyo_activated_template',$selected_template_name);
			echo "success";
			wp_die();
		}

		/**
		 * This function delete the Custom order status on the backend
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown $template
		 */
		public function mwb_mwb_delete_custom_order_status()
		{
			$mwb_tyo_old_selected_statuses = get_option('mwb_tyo_new_settings_custom_statuses_for_order_tracking',false);
			$mwb_custom_action =$_POST['mwb_custom_action'];
			$mwb_custom_key =$_POST['mwb_custom_key'];
			if(isset($mwb_custom_key) && !empty($mwb_custom_key)){
				$custom_order_status_exist = get_option( 'mwb_tyo_new_custom_order_status', array() );
				if( is_array($custom_order_status_exist) && !empty($custom_order_status_exist) ) {
					foreach($custom_order_status_exist as $key => $value){
						foreach($value as $mwb_order_key => $mwb_order_status){
							if($mwb_order_key===$mwb_custom_key)
							{
								unset($custom_order_status_exist[$key]);

							}
						}
					}
					update_option( 'mwb_tyo_new_custom_order_status', $custom_order_status_exist );

					if(is_array($mwb_tyo_old_selected_statuses) && !empty($mwb_tyo_old_selected_statuses))
					{
						foreach($mwb_tyo_old_selected_statuses as $old_key => $old_value)
						{
							if(substr($old_value,3) == $mwb_custom_key)
							{
								unset($mwb_tyo_old_selected_statuses[$old_key]);
								update_option('mwb_tyo_new_settings_custom_statuses_for_order_tracking',$mwb_tyo_old_selected_statuses);
							}
						}	
					}
					echo "success";
				}
				else
				{
					echo "failed";
				}
				
				wp_die();
			}
		}
		
		/**
		 * This function adds a track order button on order page on the frontend
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown $template
		 * @return string
		 */
		public function mwb_tyo_add_track_order_button_on_orderpage( $actions, $order )
		{
			$mwb_tyo_enable_track_order_feature = get_option( 'mwb_tyo_enable_track_order_feature', 'no' );
			if ($mwb_tyo_enable_track_order_feature != 'yes') {
				return $actions;
			}
			$mwb_tyo_enable_track_order_popup=get_option('mwb_tyo_enable_track_order_popup','no');
			$mwb_tyo_pages= get_option('mwb_tyo_tracking_page');
			$page_id = $mwb_tyo_pages['pages']['mwb_track_order_page'];
			if(WC()->version < "3.0.0")
			{
				$order_id=$order->id;
				$track_order_url = get_permalink($page_id);
				if($mwb_tyo_enable_track_order_popup =='yes')
				{
					$actions['thickbox']['url'] 	= $track_order_url.$order_id.'?TB_iframe=true';
					$actions['thickbox']['name'] 	= __( 'Track Order', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN );
				}
				else{
					$actions['mwb_track_order']['url'] 	= $track_order_url."/".$order_id;
					$actions['mwb_track_order']['name'] 	= __( 'Track Order', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN );
				}
			}
			else
			{
				$order_id=$order->get_id();
				$track_order_url = get_permalink($page_id);
				if($mwb_tyo_enable_track_order_popup =='yes')
				{
					
					$actions['thickbox']['url'] 	= $track_order_url.$order_id.'?TB_iframe=true';
					$actions['thickbox']['name'] 	= __( 'Track Order', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN );
				}
				else{
					$actions['mwb_track_order']['url'] 	= $track_order_url."/".$order_id;
					$actions['mwb_track_order']['name'] 	= __( 'Track Order', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN );
				}
				
			}

			return $actions;
		}

		/**
		 * This function is to create template for track order
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown $template
		 * @return string
		 */
		public function mwb_tyo_include_track_order_page($template)
		{
			$selected_template = get_option('mwb_tyo_activated_template');
			$mwb_tyo_google_map_setting = get_option('mwb_tyo_google_api_settings',false);
			$mwb_tyo_enable_track_order_feature = get_option( 'mwb_tyo_enable_track_order_feature', 'no' );
			if ($mwb_tyo_enable_track_order_feature != 'yes') {
				return $template;
			}
			if($mwb_tyo_enable_track_order_feature  == 'yes' && $mwb_tyo_google_map_setting == 1){
				$mwb_tyo_pages= get_option('mwb_tyo_tracking_page');
				$page_id = $mwb_tyo_pages['pages']['mwb_track_order_page'];
				if(is_page($page_id)){
					$new_template = MWB_TRACK_YOUR_ORDER_PATH.'template/mwb-map-new-template.php';
					$template = $new_template;
				}
			}
			else
			{

				$mwb_tyo_pages= get_option('mwb_tyo_tracking_page',false);
				$page_id = $mwb_tyo_pages['pages']['mwb_track_order_page'];
				if(is_page($page_id))
				{
					if($selected_template!=' ' && $selected_template!=null){
						$new_template = MWB_TRACK_YOUR_ORDER_PATH.'template/mwb-track-order-myaccount-page-'.$selected_template.'.php';
						$template =  $new_template;
					}
					else
					{
						$new_template = MWB_TRACK_YOUR_ORDER_PATH. 'template/mwb-track-order-myaccount-page-template1.php';
						$template =  $new_template;
					}
				}
			}

			return $template;
		}

		/**
		 * This function is to create template for track order
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown $template
		 * @return string
		 */
		public function mwb_tyo_include_guest_track_order_page($template)
		{
			$mwb_tyo_enable_track_order_feature = get_option( 'mwb_tyo_enable_track_order_feature', 'no' );
			if ($mwb_tyo_enable_track_order_feature != 'yes') {
				return $template;
			}
			$mwb_tyo_pages= get_option('mwb_tyo_tracking_page');
			$page_id = $mwb_tyo_pages['pages']['mwb_guest_track_order_page'];
			if(is_page($page_id))
			{
				$new_template = MWB_TRACK_YOUR_ORDER_PATH. 'template/mwb-guest-track-order-page.php';
				$template =  $new_template;
			}

			return $template;
		}
		
		/**
		 * This function is to create template for FedEX tracking of Order
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown $template
		 * @return string
		 */
		public function mwb_ordertracking_page($template)
		{
			$mwb_tyo_pages= get_option('mwb_tyo_tracking_page');
			$page_id = $mwb_tyo_pages['pages']['mwb_fedex_track_order'];
			if(is_page($page_id))
			{
				$new_template = MWB_TRACK_YOUR_ORDER_PATH. 'template/mwb-order-tracking-page.php';
				$template =  $new_template;
			}

			return $template;
		}

		/**
		 * This function is to add custom order status for return and exchange
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_tyo_register_custom_order_status()
		{
			$mwb_tyo_enable_track_order_feature = get_option( 'mwb_tyo_enable_track_order_feature', 'no' );
			$mwb_tyo_enable_custom_order_feature = get_option( 'mwb_tyo_enable_custom_order_feature', 'no' );
			if ($mwb_tyo_enable_track_order_feature != 'yes' || $mwb_tyo_enable_custom_order_feature !='yes') {
				return ;
			}
			
			register_post_status( 'wc-packed', array(
				'label'                     => __('Order Packed',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				'public'                    => true,
				'exclude_from_search'       => false,
				'show_in_admin_all_list'    => true,
				'show_in_admin_status_list' => true,
				'label_count'               => _n_noop( __('Order Packed', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ).'<span class="count">(%s)</span>', __('Order Packed', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).'<span class="count">(%s)</span>' )
				) );

			register_post_status( 'wc-dispatched', array(
				'label'                     => __('Order Dispatched',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				'public'                    => true,
				'exclude_from_search'       => false,
				'show_in_admin_all_list'    => true,
				'show_in_admin_status_list' => true,
				'label_count'               => _n_noop( __('Order Dispatched', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).' <span class="count">(%s)</span>', __('Order Dispatched', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).' <span class="count">(%s)</span>' )
				) );

			register_post_status( 'wc-shipped', array(
				'label'                     => __('Order Shipped',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN),
				'public'                    => true,
				'exclude_from_search'       => false,
				'show_in_admin_all_list'    => true,
				'show_in_admin_status_list' => true,
				'label_count'               => _n_noop( __('Order Shipped', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).' <span class="count">(%s)</span>', __('Order Shipped', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).' <span class="count">(%s)</span>' )
				) );

			$custom_statuses = get_option('mwb_tyo_new_custom_order_status',array());
			
			if (is_array($custom_statuses) && !empty( $custom_statuses )) 
			{
				foreach ($custom_statuses as $key => $value) 
				{
					foreach($value as $custom_status_key => $custom_status_value){
						register_post_status( 'wc-'.$custom_status_key, array(
							'label'                     => $custom_status_value,
							'public'                    => true,
							'exclude_from_search'       => false,
							'show_in_admin_all_list'    => true,
							'show_in_admin_status_list' => true,
							'label_count'               => _n_noop($custom_status_value.' <span class="count">(%s)</span>', $custom_status_value.' <span class="count">(%s)</span>' )
							) );
					}
				}
			}
		}

		/**
		 * This function is to register custom order status
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown $order_statuses
		 * @return multitype:string unknown
		 */
		public function mwb_tyo_add_custom_order_status($order_statuses)
		{
			$mwb_tyo_enable_track_order_feature = get_option( 'mwb_tyo_enable_track_order_feature', 'no' );
			$mwb_tyo_enable_custom_order_feature = get_option( 'mwb_tyo_enable_custom_order_feature', 'no' );
			if ($mwb_tyo_enable_track_order_feature != 'yes' || $mwb_tyo_enable_custom_order_feature !='yes') {
				return $order_statuses ;
			}
			$custom_order = get_option('mwb_tyo_new_custom_order_status',array());
			$statuses = get_option( 'mwb_tyo_new_custom_statuses_for_order_tracking' , array() );
			$mwb_tyo_statuses = get_option( 'mwb_tyo_new_settings_custom_statuses_for_order_tracking' , array() );
			
			$custom_order[] = array( 'dispatched'=> __('Order Dispatched',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN) );
			$custom_order[] = array( 'shipped'=> __('Order Shipped',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN) );
			$custom_order[] = array( 'packed'=> __('Order Packed',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN) );

			if(is_array($custom_order) && !empty($custom_order)){
				foreach ($custom_order as $key1 => $value1) {
					foreach($value1 as $custom_key => $custom_value){
						if(in_array('wc-'.$custom_key, $statuses))
						{
							$order_statuses['wc-'.$custom_key] = $custom_value;
						}
					}
				}
			}
			
			return $order_statuses;
		}
		/**
		 * This function is add Meta box for adding estimated date of delivery
		 * 
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 */
		public function mwb_tyo_tracking_order_meta_box()
		{
			$mwb_tyo_enable_track_order_feature = get_option( 'mwb_tyo_enable_track_order_feature', 'no' );
			$mwb_tyo_enable_track_17track_feature = get_option( 'mwb_tyo_enable_17track_integration', 'no' );

			if ($mwb_tyo_enable_track_order_feature != 'yes') {
				return ;
			}
			add_meta_box('mwb_tyo_track_order', __('Enter Estimated Delivery Date',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN), array($this, 'mwb_tyo_track_order_metabox'), 'shop_order', 'side');
			$mwb_tyo_enable_track_order_api = get_option('mwb_tyo_enable_third_party_tracking_api','no');
			if( $mwb_tyo_enable_track_order_api == 'yes' || $mwb_tyo_enable_track_17track_feature == 'yes' )
			{
				add_meta_box('mwb_tyo_tracking_services', __('Select Service For Tracking Your Package',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN), array($this, 'mwb_tyo_track_order_services_metabox'), 'shop_order', 'side');
			}
			$mwb_tyo_google_map_setting = get_option('mwb_tyo_google_api_settings',false);

			if($mwb_tyo_google_map_setting == 1){
				add_meta_box('mwb_tyo_custom_tracking_services', __('Select City When Your Package Reaches The Desire City',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN), array($this, 'mwb_tyo_track_order_custom_services_metabox'), 'shop_order', 'side');
			}

		}

		public function mwb_tyo_track_order_custom_services_metabox()
		{

			global $post, $thepostid, $theorder;
			if(WC()->version < "3.0.0")
			{
				$order_id = $theorder->id;
			}
			else
			{
				$order_id = $theorder->get_id();
			}
			$mwb_tyo_saved_selected_cities = get_post_meta($post->ID,'mwb_tyo_save_selected_city',true);
			// $mwb_tyo_all_selected_cities = get_option('mwb_tyo_old_addresses',false); 
			$mwb_tyo_all_selected_cities = get_option('mwb_tyo_all_tracking_address',false);
			?>
			<div class="mwb_tyo_shipping_service_wrapper">
				<select name="mwb_tyo_custom_shipping_cities" id="mwb_tyo_custom_shipping_cities">
					<option value="<?php _e('none',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN); ?>"><?php _e('Select shipping Cities',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN); ?></option>
					<?php
					if(is_array($mwb_tyo_all_selected_cities) && !empty($mwb_tyo_all_selected_cities)){
						foreach ($mwb_tyo_all_selected_cities as $custom_key => $custom_value) {
							?>
							<option value="<?php echo $custom_value; ?>" <?php if(isset($mwb_tyo_saved_selected_cities) && $mwb_tyo_saved_selected_cities != '' && $custom_value == $mwb_tyo_saved_selected_cities){ echo "selected";}?>><?php echo str_replace('mwb_address_','',$custom_value); ?></option>
							<?php
						}
					}
					?>
				</select>
			</div>
			<?php
		}

		/**
		 * This function is for estimated delivery date html 
		 * 
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown $order
		 */
		public function mwb_tyo_track_order_metabox()
		{
			global $post, $thepostid, $theorder;
			$mwb_tyo_enable_track_order_feature = get_option( 'mwb_tyo_enable_track_order_feature', 'no' );
			if ($mwb_tyo_enable_track_order_feature != 'yes') {
				return ;
			}
			if(WC()->version < "3.0.0")
			{
				$order_id = $theorder->id;
			}
			else
			{
				$order_id = $theorder->get_id();
			}
			$expected_delivery_date = get_post_meta( $order_id, 'mwb_tyo_estimated_delivery_date', true );
			$expected_delivery_time = get_post_meta( $order_id, 'mwb_tyo_estimated_delivery_time', true );

			?>
			<div class="mwb_tyo_estimated_delivery_datails_wrapper">
				<label for="mwb_tyo_est_delivery_date"><?php _e( 'Delivery Date',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN  ) ?></label>
				<input type="text" class="mwb_tyo_est_delivery_date" id="mwb_tyo_est_delivery_date" name="mwb_tyo_est_delivery_date" value="<?php echo $expected_delivery_date; ?>" placeholder="<?php _e( 'Enter Delivery Date', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ); ?>"></input>
				<label for="mwb_tyo_est_delivery_time"><?php _e( 'Delivery Time',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN  ) ?></label>
				<input type="text" class="mwb_tyo_est_delivery_time" name="mwb_tyo_est_delivery_time" id="mwb_tyo_est_delivery_time" value="<?php echo $expected_delivery_time; ?>" placeholder="<?php _e( 'Enter Delivery time', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ); ?>"></input>
			</div>
			<?php
		}


		/**
		 * This function is for different shipping services html 
		 * 
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown 
		 */

		public function mwb_tyo_track_order_services_metabox()
		{
			global $post, $thepostid, $theorder;
			$mwb_tyo_enable_track_order_api = get_option('mwb_tyo_enable_third_party_tracking_api','no');
			$mwb_tyo_enable_track_17track_feature = get_option( 'mwb_tyo_enable_17track_integration', 'no' );
			// if ($mwb_tyo_enable_track_order_api != 'yes') {
			// 	return ;
			// }
			// elseif($mwb_tyo_enable_track_17track_feature != 'yes'){
			// 	return;
			// }
			if(WC()->version < "3.0.0")
			{
				$order_id = $theorder->id;
			}
			else
			{
				$order_id = $theorder->get_id();
			}
			$mwb_diffrent_shipping_services = array("fedex"=>"FedEx");
			$mwb_diffrent_shipping_services = apply_filters('mwb_tyo_add_diffrent_shipping_services',$mwb_diffrent_shipping_services);
			$mwb_tyo_track_id = get_post_meta($order_id,'mwb_tyo_package_tracking_number',true);
			$selected_method = get_post_meta($order_id,'mwb_tyo_selected_shipping_service',true);
			if ($mwb_tyo_enable_track_order_api == 'yes') {
				?>
				<div class="mwb_tyo_shipping_service_wrapper">
					<select name="mwb_tyo_selected_shipping_services">
						<option><?php _e('---Select shipping Services---',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN); ?></option>
						<?php if(isset($mwb_diffrent_shipping_services) && !empty($mwb_diffrent_shipping_services)){
							foreach($mwb_diffrent_shipping_services as $key => $value)
								{?>
							<option value="<?php echo $key; ?>"<?php if( $key == $selected_method ){ echo 'selected'; } ?>><?php echo $value; ?></option>
							<?php
						}
					}?>
				</select>
			</div>
			<div class="mwb_tyo_ship_tracking_wrapper">
				<label for="mwb_tyo_user_tracking_number"><?php _e( 'Tracking Number',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN  ) ?></label>
				<input type="text" name="mwb_tyo_tracking_number" id="mwb_tyo_tracking_number" value="<?php echo $mwb_tyo_track_id; ?>" placeholder="<?php _e( 'Enter Tracking Number', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ); ?>"></input>
			</div>
			<?php
		}
		elseif($mwb_tyo_enable_track_17track_feature == 'yes'){
			?>
			<div class="mwb_tyo_ship_tracking_wrapper">
				<label for="mwb_tyo_user_tracking_number"><?php _e( '17Track Number',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN  ) ?></label>
				<input type="text" name="mwb_tyo_tracking_number" id="mwb_tyo_tracking_number" value="<?php echo $mwb_tyo_track_id; ?>" placeholder="<?php _e( 'Enter 17 Tracking Number', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ); ?>"></input>
			</div>
			<?php
		}
	}

		/**
		 * This function is for saving delivery date
		 * 
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown 
		 */

		public function mwb_tyo_save_delivery_date_meta()
		{
			global $post;
			if(isset($post->ID))
			{	
				$mwb_track_order_status = array();
				$post_id = $post->ID;
				if ( isset( $_POST['mwb_tyo_est_delivery_date'] ) && $_POST['mwb_tyo_est_delivery_date'] != '' ) 
				{
					update_post_meta( $post_id, 'mwb_tyo_estimated_delivery_date', $_POST['mwb_tyo_est_delivery_date'] );
				}
				else 
				{
					update_post_meta($post_id, 'mwb_tyo_estimated_delivery_date', false);
				}

				if ( isset( $_POST['mwb_tyo_est_delivery_time'] ) && $_POST['mwb_tyo_est_delivery_time'] != '' ) 
				{
					update_post_meta( $post_id, 'mwb_tyo_estimated_delivery_time', $_POST['mwb_tyo_est_delivery_time'] );
				}
				else 
				{
					update_post_meta($post_id, 'mwb_tyo_estimated_delivery_time', false);
				}
			}
		}

			/**
		 * This function is for saving delivery date
		 * 
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown 
		 */
			public function mwb_tyo_save_custom_shipping_cities_meta(){
				global $post;
				if(isset($post->ID)){
					$order = wc_get_order($post->ID);
					if(isset($order) && !empty($order)){

						$orderdata = $order->get_data();
						$order_modified_date = $orderdata['date_modified'];
						$converted_order_modified_date = date_i18n('F d, Y g:i a',strtotime($order_modified_date));
						$current_order_status = $order->get_status();
						
						$mwb_tyo_all_selected_cities = get_option('mwb_tyo_old_addresses',false); 
						$mwb_tyo_previous_saved_cities = get_post_meta($post->ID,'mwb_tyo_track_custom_cities',true);
						$mwb_tyo_previous_saved_changed_time = get_post_meta($post->ID,'mwb_tyo_custom_change_time',true);
						
						if(isset($_POST['mwb_tyo_custom_shipping_cities']) && $_POST['mwb_tyo_custom_shipping_cities'] != '')
						{
							if(isset($mwb_tyo_previous_saved_cities) && $mwb_tyo_previous_saved_cities == '')
							{
								if(array_key_exists($_POST['mwb_tyo_custom_shipping_cities'], $mwb_tyo_all_selected_cities))
								{

									$mwb_tyo_previous_saved_cities[$current_order_status][] =  $mwb_tyo_all_selected_cities[$_POST['mwb_tyo_custom_shipping_cities']];
									$mwb_tyo_previous_saved_changed_time[$current_order_status][] =  $converted_order_modified_date;
									update_post_meta($post->ID,'mwb_tyo_track_custom_cities',$mwb_tyo_previous_saved_cities);
									update_post_meta($post->ID,'mwb_tyo_custom_change_time',$mwb_tyo_previous_saved_changed_time);
								}
							}
							else
							{
								if(array_key_exists($_POST['mwb_tyo_custom_shipping_cities'], $mwb_tyo_all_selected_cities))
								{

									$mwb_tyo_previous_saved_cities[$current_order_status][] =  $mwb_tyo_all_selected_cities[$_POST['mwb_tyo_custom_shipping_cities']];
									$mwb_tyo_previous_saved_changed_time[$current_order_status][] =  $converted_order_modified_date;
									update_post_meta($post->ID,'mwb_tyo_track_custom_cities',$mwb_tyo_previous_saved_cities);
									update_post_meta($post->ID,'mwb_tyo_custom_change_time',$mwb_tyo_previous_saved_changed_time);
								}
							}
							
							update_post_meta($post->ID,'mwb_tyo_save_selected_city',$_POST['mwb_tyo_custom_shipping_cities']);
						}
					}
				}
			}




		/**
		 * This function is for saving shipping services meta data 
		 * 
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown 
		 */
		public function mwb_tyo_save_shipping_services_meta()
		{
			global $post;
			if(isset($post->ID))
			{
				$post_id = $post->ID;
				if(isset($_POST['mwb_tyo_selected_shipping_services']) && isset($_POST['mwb_tyo_tracking_number']) && $_POST['mwb_tyo_tracking_number'] != '' && !empty($_POST['mwb_tyo_selected_shipping_services']))
				{  
					update_post_meta($post_id,'mwb_tyo_selected_shipping_service',$_POST['mwb_tyo_selected_shipping_services']);
					update_post_meta($post_id,'mwb_tyo_package_tracking_number',$_POST['mwb_tyo_tracking_number']);

					$headers = array();
					$order = wc_get_order( $post_id );
					$headers[] = "Content-Type: text/html; charset=UTF-8";
					$mwb_tracking_url = get_post_meta($order_id,'mwb_tyo_enhanced_order_company',true);
					$mwb_tracking_number=get_post_meta($order_id,'mwb_tyo_enhanced_tracking_no',true);
					if( WC()->version < '3.0.0' )
					{
						$fname = get_post_meta($post_id, '_billing_first_name', true);
						$lname = get_post_meta($post_id, '_billing_last_name', true);
						$to = get_post_meta($post_id, '_billing_email', true);
					}
					else{
						$mwb_all_data=$order->get_data();
						$billing_address=$mwb_all_data['billing'];
						$shipping_address=$mwb_all_data['shipping'];
						$to=$billing_address['email'];
					}
					$subject =__('Your Order Status for Order #',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).$post_id;
					$message =__('Your Order Status is ',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).$statuses[$new_status];
					$mail_header =__('Current Order Status is ',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).$statuses[$new_status];
					$mail_footer ='';
					$message = '<html>
					<body>
						<style>
							body {
								box-shadow: 2px 2px 10px #ccc;
								color: #767676;
								font-family: Arial,sans-serif;
								margin: 80px auto;
								max-width: 700px;
								padding-bottom: 30px;
								width: 100%;
							}

							h2 {
								font-size: 30px;
								margin-top: 0;
								color: #fff;
								padding: 40px;
								background-color: #557da1;
							}

							h4 {
								color: #557da1;
								font-size: 20px;
								margin-bottom: 10px;
							}

							.content {
								padding: 0 40px;
							}

							.Customer-detail ul li p {
								margin: 0;
							}

							.details .Shipping-detail {
								width: 40%;
								float: right;
							}

							.details .Billing-detail {
								width: 60%;
								float: left;
							}

							.details .Shipping-detail ul li,.details .Billing-detail ul li {
								list-style-type: none;
								margin: 0;
							}

							.details .Billing-detail ul,.details .Shipping-detail ul {
								margin: 0;
								padding: 0;
							}

							.clear {
								clear: both;
							}

							table,td,th {
								border: 2px solid #ccc;
								padding: 15px;
								text-align: left;
							}

							table {
								border-collapse: collapse;
								width: 100%;
							}

							.info {
								display: inline-block;
							}

							.bold {
								font-weight: bold;
							}

							.footer {
								margin-top: 30px;
								text-align: center;
								color: #99B1D8;
								font-size: 12px;
							}
							dl.variation dd {
								font-size: 12px;
								margin: 0;
							}
						</style>

						<div style="padding: 36px 48px; background-color:#557DA1;color: #fff; font-size: 30px; font-weight: 300; font-family:helvetica;" class="header">
							'.$mail_header.'
						</div>		

						<div class="content">

							<div class="Order">
								<h4>Order #'.$post_id.'</h4>
								<table>
									<tbody>
										<tr>
											<th>'.__('Order Id', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).'</th>
											<th>'.__('Tracking Number ', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).'</th>
										</tr>';
										$mwb_user_tracking_number = get_post_meta($post_id,'mwb_tyo_package_tracking_number',true);
										$message .= '<tr>
										<td>'.$mwb_user_tracking_number.'</td>
									</tr>';
									$message .= '</tbody>
								</table>
								<div>
									<a href='.$mwb_tracking_url.'>'.$mwb_tracking_number.'</a>
								</div>
							</div>
						</div>
						<div style="text-align: center; padding: 10px;" class="footer">
							'.$mail_footer.'
						</div>
					</body>
					</html>';
					$mwb_mail_already_send = get_post_meta($post_id,'mwb_tyo_tracking_id_sent',true);
					if($mwb_mail_already_send !=1){
						wc_mail( $to, $subject, $message, $headers );
						update_post_meta($post_id,'mwb_tyo_tracking_id_sent',1);
					}
				}
				elseif( isset($_POST['mwb_tyo_tracking_number']) && $_POST['mwb_tyo_tracking_number'] != ''){
					update_post_meta($post_id,'mwb_tyo_package_tracking_number',$_POST['mwb_tyo_tracking_number']);
				}
				else
				{
					update_post_meta($post_id,'mwb_tyo_selected_shipping_service','');
					update_post_meta($post_id,'mwb_tyo_package_tracking_number','');
				}
			}
		}


		/**
		 * This function is for sending mail when the order status will change 
		 * 
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown 
		 */

		

		public function mwb_tyo_track_order_status( $order_id , $old_status, $new_status )
		{	
			$old_status = 'wc-'.$old_status;
			$new_status = 'wc-'.$new_status;
			$mwb_tyo_email_notifier=get_option('mwb_tyo_email_notifier','no');
			$order = new WC_Order( $order_id );
			if(WC()->version < '3.0.0')
			{
				$mwb_date_on_order_change=$order->modified_date;

			}
			else
			{
				$change_order_status=$order->get_data()['status'];
				$date_on_order_change=$order->get_data();
				$mwb_date_on_order_change=$date_on_order_change['date_modified']->date;	

			}
			$mwb_modified_date=date_i18n( wc_date_format(), strtotime( $mwb_date_on_order_change )).date_i18n( wc_time_format(), strtotime( $mwb_date_on_order_change ));

			$mwb_status_change_time = array();
			$mwb_status_change_time_temp = array();
			$mwb_status_change_time = get_post_meta( $order_id, 'mwb_track_order_onchange_time', true );
			$mwb_status_change_time_temp = get_post_meta( $order_id, 'mwb_track_order_onchange_time_temp', true );
			$mwb_status_change_time_template2 = get_post_meta( $order_id, 'mwb_track_order_onchange_time_template', true );

			$order_index = 'wc-'.$change_order_status;
			if(is_array($mwb_status_change_time_temp) && !empty($mwb_status_change_time_temp)){
				$mwb_status_change_time[$order_index]=$mwb_modified_date;
			}else{
				
				$mwb_status_change_time[$order_index]=$mwb_modified_date;
			}
			if(is_array($mwb_status_change_time_temp) && !empty($mwb_status_change_time_temp)){

				$mwb_status_change_time_temp[$order_index]=$mwb_modified_date;
			}else{
				
				$mwb_status_change_time_temp[$order_index]=$mwb_modified_date;
			}
			if(is_array($mwb_status_change_time_template2) && !empty($mwb_status_change_time_template2)){

				$mwb_status_change_time_template2[][$order_index]=$mwb_modified_date;
			}

			$statuses = wc_get_order_statuses();

			$mwb_track_order_status = get_post_meta( $order_id, 'mwb_track_order_status',true );
			if ( is_array($mwb_track_order_status) && !empty($mwb_track_order_status) ) {
				
				$c = count($mwb_track_order_status);
				if ($mwb_track_order_status[$c-1] == $old_status) {
					if (in_array( $new_status , $mwb_track_order_status )) {
						$key = array_search ( $new_status, $mwb_track_order_status );
						unset( $mwb_track_order_status[$key] );
						$mwb_track_order_status = array_values($mwb_track_order_status);
					}
					$mwb_track_order_status[] = $new_status;
					update_post_meta( $order_id, 'mwb_track_order_status', $mwb_track_order_status );
					update_post_meta($order_id,'mwb_track_order_onchange_time',$mwb_status_change_time);
					update_post_meta($order_id,'mwb_track_order_onchange_time_temp',$mwb_status_change_time_temp);
					update_post_meta($order_id,'mwb_track_order_onchange_time_template',$mwb_status_change_time_template2);
				}else{

					$mwb_track_order_status[] = $old_status;
					$mwb_track_order_status[] = $new_status;
					update_post_meta( $order_id, 'mwb_track_order_status', $mwb_track_order_status );
					update_post_meta($order_id,'mwb_track_order_onchange_time',$mwb_status_change_time);
					update_post_meta($order_id,'mwb_track_order_onchange_time_temp',$mwb_status_change_time_temp);
					update_post_meta($order_id,'mwb_track_order_onchange_time_template',$mwb_status_change_time_template2);
				}
			}
			else{

				$mwb_status_change_time = array();
				$mwb_status_change_time_temp = array();
				$mwb_status_change_time_template2 = array();
				$mwb_track_order_status = array();
				$mwb_track_order_status[] = $old_status;
				$mwb_track_order_status[] = $new_status;
				
				update_post_meta( $order_id, 'mwb_track_order_status', $mwb_track_order_status );
				update_post_meta($order_id,'mwb_track_order_onchange_time',$mwb_status_change_time);
				update_post_meta($order_id,'mwb_track_order_onchange_time_temp',$mwb_status_change_time_temp);
				update_post_meta($order_id,'mwb_track_order_onchange_time_template',$mwb_status_change_time_template2);
			}
			
			if($mwb_tyo_email_notifier=='yes' && $new_status != 'wc-completed')
			{
				if(WC()->version < '3.0.0'){
					$order_id=$order->id;
					$headers = array();
					$headers[] = "Content-Type: text/html; charset=UTF-8";
					$fname = get_post_meta($order_id, '_billing_first_name', true);
					$lname = get_post_meta($order_id, '_billing_last_name', true);
					$to = get_post_meta($order_id, '_billing_email', true);
					$subject =__('Your Order Status for Order #',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).$order_id;
					$message =__('Your Order Status is ',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).$statuses[$new_status];
					$mail_header =__('Current Order Status is ',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).$statuses[$new_status];
					$mail_footer ='';

				}
				else
				{
					$headers = array();
					$headers[] = "Content-Type: text/html; charset=UTF-8";
					$mwb_all_data=$order->get_data();
					$billing_address=$mwb_all_data['billing'];
					$shipping_address=$mwb_all_data['shipping'];
					$to=$billing_address['email'];
					$subject =__('Your Order Status for Order #',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).$order_id;
					$message =__('Your Order Status is ',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).$statuses[$new_status];
					$mail_header =__('Current Order Status is ',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).$statuses[$new_status];
					$mail_footer ='';

				}

				$message = '<html>
				<body>
					<style>
						body {
							box-shadow: 2px 2px 10px #ccc;
							color: #767676;
							font-family: Arial,sans-serif;
							margin: 80px auto;
							max-width: 700px;
							padding-bottom: 30px;
							width: 100%;
						}

						h2 {
							font-size: 30px;
							margin-top: 0;
							color: #fff;
							padding: 40px;
							background-color: #557da1;
						}

						h4 {
							color: #557da1;
							font-size: 20px;
							margin-bottom: 10px;
						}

						.content {
							padding: 0 40px;
						}

						.Customer-detail ul li p {
							margin: 0;
						}

						.details .Shipping-detail {
							width: 40%;
							float: right;
						}

						.details .Billing-detail {
							width: 60%;
							float: left;
						}

						.details .Shipping-detail ul li,.details .Billing-detail ul li {
							list-style-type: none;
							margin: 0;
						}

						.details .Billing-detail ul,.details .Shipping-detail ul {
							margin: 0;
							padding: 0;
						}

						.clear {
							clear: both;
						}

						table,td,th {
							border: 2px solid #ccc;
							padding: 15px;
							text-align: left;
						}

						table {
							border-collapse: collapse;
							width: 100%;
						}

						.info {
							display: inline-block;
						}

						.bold {
							font-weight: bold;
						}

						.footer {
							margin-top: 30px;
							text-align: center;
							color: #99B1D8;
							font-size: 12px;
						}
						dl.variation dd {
							font-size: 12px;
							margin: 0;
						}
					</style>

					<div style="padding: 36px 48px; background-color:#557DA1;color: #fff; font-size: 30px; font-weight: 300; font-family:helvetica;" class="header">
						'.$mail_header.'
					</div>		

					<div class="content">

						<div class="Order">
							<h4>Order #'.$order_id.'</h4>
							<table>
								<tbody>
									<tr>
										<th>'.__('Product', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).'</th>
										<th>'.__('Quantity', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).'</th>
										<th>'.__('Price', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).'</th>
									</tr>';

									$order = new WC_Order($order_id);
									$total = 0;
									foreach ($order->get_items() as $item_id => $item) 
									{
										$product = apply_filters( 'woocommerce_order_item_product', $order->get_product_from_item( $item ), $item );
										$item_meta      = new WC_Order_Item_Meta( $item, $product );
										$item_meta_html = $item_meta->display( true, true );

										$message .= '<tr>
										<td>'.$item['name'].'<br>';
											$message .= '<small>'.$item_meta_html.'</small>
											<td>'.$item['qty'].'</td>
											<td>'.wc_price( $product->get_price() ).'</td>
										</tr>';
										$total = $total + ( $product->get_price() * $item['qty'] );
									}
									$message .= '<tr>
									<th colspan = "2">'.__('Total', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).'</th>
									<td>'.wc_price($total).'</td>';
									$message .= '</tbody>
								</table>
							</div>
							<div class="Customer-detail">
								<h4>'.__('Customer details', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).'</h4>
								<ul>
									<li>
										<p class="info">
											<span class="bold">'.__('Email',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).': </span>'.get_post_meta($order->id, '_billing_email', true).'
										</p>
									</li>
									<li>
										<p class="info">
											<span class="bold">'.__('Tel',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).': </span>'.get_post_meta($order->id, '_billing_phone', true).'
										</p>
									</li>
								</ul>
							</div>
							<div class="details">
								<div class="Shipping-detail">
									<h4>'.__('Shipping Address', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).'</h4>
									'.$order->get_formatted_shipping_address().'
								</div>
								<div class="Billing-detail">
									<h4>'.__('Billing Address', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN).'</h4>
									'.$order->get_formatted_billing_address().'
								</div>
								<div class="clear"></div>
							</div>
						</div>
						<div style="text-align: center; padding: 10px;" class="footer">
							'.$mail_footer.'
						</div>
					</body>
					</html>';
					wc_mail( $to, $subject, $message, $headers );

				}
			}





		/**
		 * This function is for rendering track order button 
		 * 
		 * @author makewebbetter<webmaster@makewebbetter.com>
		 * @link http://www.makewebbetter.com/
		 * @param unknown 
		 */

		public function mwb_tyo_track_order_button( $order )
		{
			if(WC()->version < "3.0.0")
			{
				$order_id = $order->id;
			}
			else
			{
				$order_id = $order->get_id();
			}
			$mwb_tyo_enable_track_order_feature = get_option( 'mwb_tyo_enable_track_order_feature', 'no' );
			$mwb_tyo_enable_track_order_popup=get_option('mwb_tyo_enable_track_order_popup','no');
			if ($mwb_tyo_enable_track_order_feature != 'yes') {
				return ;
			}
			if($mwb_tyo_enable_track_order_popup!='yes'){
				$mwb_tyo_pages= get_option('mwb_tyo_tracking_page');
				$page_id = $mwb_tyo_pages['pages']['mwb_track_order_page'];
				$track_order_url = get_permalink($page_id);
				?>
				<p><label class="mwb_enhanced_order_note"><?php _e('Note:',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN);?></label><span class="mwb_order_note_text"><?php _e('Click The Below To Track Your Order',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN);?></span><p>
					<a href="<?php echo $track_order_url.'/'.$order_id ?>" class="button button-primary"><?php _e( 'TRACK ORDER', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ); ?></a>

					<?php
				}
				else
				{
					$mwb_tyo_pages= get_option('mwb_tyo_tracking_page');
					$page_id = $mwb_tyo_pages['pages']['mwb_track_order_page'];
					$track_order_url = get_permalink($page_id);
					add_thickbox();
					$order_number = get_post_meta( $order_id, '_order_number', true );
					$prefix='';
					$prefix = get_option('woocommerce_order_number_prefix',false);
					if(!empty($order_number))
					{
						$order_number=$prefix.$order_number;	
					}
					else{
						$order_number=$order_id;
					}
					if($_SERVER['REMOTE_ADDR'] == '103.97.184.162'){
						?>

						<p><label class="mwb_enhanced_order_note"><?php _e('Note:',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN);?></label><span class="mwb_order_note_text"><?php _e('Click The Below To Track Your Order',MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN);?></span><p>
							<?php }?>
							<a href="<?php echo $track_order_url.'/'.$order_id.'?TB_iframe=true&width=850' ?>" class="button button-primary thickbox"  title = "<?php echo __( 'Order status for - ', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ).$order_number; ?>"><?php _e( 'TRACK ORDER', MWB_TRACK_YOUR_ORDER_TEXT_DOMAIN ); ?></a>
							<?php
						}
					}


				}
				new MWB_Track_Your_Order();
			}
